/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef szrth
#define szrth

#include  <QGraphicsEllipseItem>
#include  "con.h"
#include  <QList>

class QColor;
class QString;
class QGraphicsSceneMouseEvent;
class felu;
class rslt;

class szrt: public QGraphicsEllipseItem
<%
	public:
		szrt(felu *fldlgz, rslt *alkt);

		int type() const <% return gratype(19); %>
		felu *korrkt;

		rslt *cel;
		void paint(QPainter *, const QStyleOptionGraphicsItem *, QWidget *);

%>;

#endif

